@@ -7,8 +7,8 @@
 #include <config.h>
 
 #include <asiolink/io_service.h>
+#include <d2srv/testutils/nc_test_utils.h>
 #include <d2/d2_update_mgr.h>
-#include <nc_test_utils.h>
 #include <d2/nc_add.h>
 #include <d2/nc_remove.h>
 #include <d2/simple_add.h>
